<?php
/*******************************************************************************
*    myMVC - Model-View-Controller for PHP                                     *
*    Copyright (C) 2012 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU Lesser General Public License as published  *
*    by the Free Software Foundation; version 2.1 of the License.              *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU Lesser General Public License for more details.                       *
*                                                                              *
*    You should have received a copy of the GNU Lesser General Public License  *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

/**
 * Generic class to query the database
 */
class myMVC_GenericSQL extends myMVC_BaseDB
{
  /**
   * Constructor.
   */
  public function __construct()
  {
    parent::__construct('', array(), array());
  }

  /**
   * Sends the given query to the engine an returns the result as array
   * 
   * @param string $sql                         The SQL query
   * @param boolean $linear                     If true, all data will returned as <b>one</b> numeric array,
   *                                            otherwise (default) they will returned as array of arrays
   * @param $assoc                              If true data will be returned as associative array. Default: false
   * @return array                              The result as array of arrays or NULL if no data was found
   * @throws myMVC_DatabaseException            On generic problem
   */
  public static function executeQuery($sql, $linear = false, $assoc = false)
  {
    $db = new myMVC_GenericSQL();
    if(($result = $db->engine->executeSelect($sql)) !== false)
    {
      if($db->engine->getRowsNum($result) == 0)
        return NULL;
      $ret = array();
      if($assoc)
      {
        while($row = $db->engine->getValueArrayFromResult($result))
        {
          if($linear)
            $ret = array_merge($ret, $row);
          else
            $ret[] = $row;
        }
      }
      else
      {
        while($row = $db->engine->getValuesFromResult($result))
        {
          if($linear)
            $ret = array_merge($ret, $row);
          else
            $ret[] = $row;
        }
      }
      $db->engine->freeResult($result);
      return $ret;
    }
    else
      throw new myMVC_DatabaseException(sprintf("Error on SQL query. Errno: %d - %s", $db->engine->errno(), $db->engine->error()));
  }

  /**
   * Quotes a string to use in a SQL-Query
   *
   * @param  string $value      The string with the Query
   * @return string             A secure SQL-String (quoted)
   */
  public static function quoteSql($value)
  {
    $db = new myMVC_GenericSQL();
    return $db->engine->quoteSqlString($value);
  }

  /**
   * Quotes a string to use in a SQL-Query (with LIKE)
   *
   * @param  string $value      The string with the Query
   * @param  string $prefix     (normally %) added BEFORE the string
   * @param  string $suffix     (normally %) added AFTER the string
   * @return string             A secure SQL-String (quoted)
   */
  public static function quoteSqlForLike($value, $prefix = '%', $suffix = '%')
  {
    $db = new myMVC_GenericSQL();
    return $db->engine->quoteSqlStringForLike($value, $prefix, $suffix);
  }
}
?>
